G4F Chat
Description: A conversational AI system that listens, learns, and challenges

Settings
Enable Dark Mode
Web Access with DuckDuckGo
Disable Conversation History
Hide System-prompt
Download generated media
Refine files with spaCy
Track usage
Report errors
Count words and tokens
Automatic Orientation (16:9 or 9:16)
System prompt
Input max. height
Speech recognition language
Enable Memory with Mem0
Mem0 API:
Custom Provider (Base Url):
Custom Provider:
Microsoft Designer in Bing:
New Conversation
Logs